SUBROUTINE evodiskg(time,dt,ndisk,Rdisk,Sigmag,taudisk,Mgdisk,gasdisk,ap,Hdisk)

!(c) Christoph Mordasini, University of Bern, 2015
!evolve the gas disk

IMPLICIT NONE
INCLUDE 'units.h90'
INTEGER,INTENT(IN)                                ::ndisk
DOUBLE PRECISION,INTENT(IN)                       ::time,dt,taudisk,ap
DOUBLE PRECISION,DIMENSION(ndisk),INTENT(IN)      ::Rdisk
DOUBLE PRECISION,DIMENSION(ndisk),INTENT(INOUT)   ::Sigmag,Hdisk
DOUBLE PRECISION,INTENT(OUT)                      ::Mgdisk
LOGICAL,INTENT(OUT)                               ::gasdisk
LOGICAL,PARAMETER                                 ::DEBUG=.FALSE.,photoevap=.TRUE.
INTEGER                                           ::i,ip
DOUBLE PRECISION                                  ::dsigmagdt,Mdotevap
DOUBLE PRECISION,PARAMETER                        ::Sigmagmin=1D0  !must be the same as in sbr mdotcore

IF(DEBUG)THEN
   WRITE(*,*)
   WRITE(*,*)'SBR EVODISK'
END IF

IF(DEBUG)WRITE(*,*)Sigmag(1),Sigmag(ndisk),taudisk/an

DO i=1,ndisk
   dsigmagdt=-Sigmag(i)/taudisk
   IF(photoevap)THEN
      Mdotevap=1D-7*Msol/an
      dsigmagdt=dsigmagdt-Mdotevap/(PI*(100D0*AU)**2D0)
   END IF

   sigmag(i)=MAX(0D0,sigmag(i)+dt*dsigmagdt)
 
END DO

IF(DEBUG)WRITE(*,*)Sigmag(1),Sigmag(ndisk)


!----------------------------------------------------
!get the gas surface density at the planet's position
!----------------------------------------------------
ip=0
DO i=1,ndisk-1
   IF(Rdisk(i)<=ap.AND.Rdisk(i+1)>=ap)THEN
      ip=i
      IF(DEBUG)WRITE(*,*)ip,ap/AU,Rdisk(ip)/AU,sigmag(ip)
      EXIT
   END IF
END DO

IF(sigmag(ip)>sigmagmin)THEN
   gasdisk=.TRUE.
ELSE
   gasdisk=.FAlSE.
END IF

!Calculate the total disk masse
Mgdisk=0D0
DO i=1,ndisk-1
   Mgdisk=Mgdisk+2D0*PI*0.5*(Rdisk(i+1)+Rdisk(i))*(Rdisk(i+1)-Rdisk(i))*0.5D0*(Sigmag(i+1)+Sigmag(i))
END DO

IF(Mgdisk/Msol<1D-6)THEN
   Sigmag=0D0
   Hdisk=0D0
!   STOP'Mgdisk/Msol<1D-6'
END IF

RETURN
END SUBROUTINE evodiskg
