SUBROUTINE initdisk(ndisk,Rindisk,Routdisk,fg,feh,Mstar,pT,fpgsun,Rdisk,Sigmag,Sigmad,Tdisk,Hdisk,Mgdisk,Mddisk,aice)

!(c) Christoph Mordasini, University of Bern, 2015
!creates an initial protoplanetary disk

IMPLICIT NONE
INCLUDE 'units.h90'
INTEGER,INTENT(IN)                             ::ndisk
DOUBLE PRECISION,INTENT(IN)                    ::Rindisk,Routdisk,fg,feh,Mstar,pT,fpgsun
DOUBLE PRECISION,INTENT(OUT)                   ::Mgdisk,Mddisk,aice
DOUBLE PRECISION,DIMENSION(ndisk),INTENT(OUT)  ::Rdisk,Sigmag,Sigmad,Tdisk,Hdisk
DOUBLE PRECISION                               ::delta,etaice,Omega,csound,pg,yloc,yderi
DOUBLE PRECISION,PARAMETER                     ::mu=2.4D0,Rmini=0.005D0*AU,Rmaxi=1000D0*AU
INTEGER                                        ::i
LOGICAL,PARAMETER                              ::DEBUG=.FALSE.,DDEBUG=.FALSE.,FIXPG=.FALSE.
 
IF(DEBUG)THEN
   WRITE(*,*)
   WRITE(*,*)'SBR INITGASDISK'
   WRITE(*,*)'Mstar/Msol',Mstar/Msol
   WRITE(*,*)'fg,feh,pT ',fg,feh,pT
   WRITE(*,*)'Rin,Rout  ',Rindisk,Routdisk
   READ(*,*)
END IF

!In a viscously heated disk the power law exponent of the disk temperature 
!gives the power law exponent of the gas surface density
pg=-pt-3D0/2D0

!However, we may want to fix pg to some value as in IL04
IF(FIXPG)THEN
   pg=-1.5D0
END IF

!create uniform in log grid in radius, set the gas
DO i=1,ndisk
   !create uniform in log grid in radius
   delta=(LOG(Rmaxi)-LOG(Rmini))/(ndisk-1.)
   Rdisk(i)=Rmini*EXP(delta*(i-1.))
   !set the disk temperature for a passively irradiated disk
   Tdisk(i)=280D0*(Rdisk(i)/AU)**pt*(Mstar/Msol)
   !set the gas surface density
   IF((Rdisk(i)/Routdisk)**(2D0-pg)<10D0)THEN
      Sigmag(i)=2400D0*fg*(Rdisk(i)/AU)**pg*EXP(-(Rdisk(i)/Routdisk)**(2D0-pg))*(1D0-MIN(1D0,SQRT(Rindisk/Rdisk(i))))
   ELSE
      Sigmag(i)=0d0
   END IF
   !set the scale height
   Omega=(G*Mstar/rdisk(i)**3D0)**0.5
   !calculate the sound speed
   csound=(kB*Tdisk(i)/(mu*uma))**0.5D0
   Hdisk(i)=csound/Omega
END DO

!get the iceline position
aice=0D0
Do i=1,ndisk-1
   IF(Tdisk(i)>=170D0.AND.Tdisk(i+1)<170D0)aice=Rdisk(i)
END DO
IF(aice==0D0)STOP'ERROR IN SBR INITDISK: no iceline found'

!set the dust surface density
Do i=1,ndisk-1
   IF(rdisk(i)<aice)THEN
      etaice=0.25D0
   ELSE
      etaice=1D0
   END IF
   !Set the solid surface density. fpgsun (0.0149) is the heavy element mass fraction of the Sun. IL04 have 10 g/cm**2 at 1 AU.
   Sigmad(i)=fpgsun*10D0**feh*etaice*Sigmag(i)
END DO

   
!Calculate the initial masses
Mgdisk=0D0
Mddisk=0D0

DO i=1,ndisk-1
   Mgdisk=Mgdisk+2D0*PI*0.5*(Rdisk(i+1)+Rdisk(i))*(Rdisk(i+1)-Rdisk(i))*0.5D0*(Sigmag(i+1)+Sigmag(i))
   Mddisk=Mddisk+2D0*PI*0.5*(Rdisk(i+1)+Rdisk(i))*(Rdisk(i+1)-Rdisk(i))*0.5D0*(Sigmad(i+1)+Sigmad(i))
END DO

IF(DEBUG)THEN
   WRITE(*,*)
   WRITE(*,*)'Ice line aice/AU                ',aice/AU
   WRITE(*,*)'Initial gas disk Msol,MJ,Mearth ',Mgdisk/Msol,Mgdisk/MJ,Mgdisk/Mearth
   WRITE(*,*)'Initial dust disk Msol,MJ,Mearth',Mddisk/Msol,Mddisk/MJ,Mddisk/Mearth
END IF

!write out initial disk structure
IF(DDEBUG)THEN
   DO i=1,ndisk
      IF(Sigmag(i)>0D0)THEN
         call drivequadradisk(Ndisk,Rdisk,Sigmag,Rdisk(i),yloc,yderi)
         yderi=yderi*Rdisk(i)/Sigmag(i)
      ELSE
         yloc=0D0
         yderi=0D0
      END IF

      WRITE(14,'(100G15.5)')i,Rdisk(i)/AU,Tdisk(i),Sigmag(i),Sigmad(i),Hdisk(i)/AU,yloc,yderi
   END DO
END IF

RETURN
END SUBROUTINE initdisk
