subroutine makeinitcond(NMC,MAXPARAMS,distkind,params,idum,MStar,Rindisk,Routdisk,feh,fg,taudisk,ap)

!(c) Christoph Mordasini, University of Bern, 2015
!Draws random variables from 8 different probability distributions

IMPLICIT NONE
INCLUDE 'units.h90'

INTEGER,INTENT(IN)                           ::NMC,MAXPARAMS
INTEGER,DIMENSION(NMC)                       ::distkind 
DOUBLE PRECISION,DIMENSION(NMC,MAXPARAMS)    ::params
INTEGER,INTENT(INOUT)                        ::idum
DOUBLE PRECISION,INTENT(OUT)                 ::MStar,Rindisk,Routdisk,feh,fg,taudisk,ap
INTEGER                                      ::i
LOGICAL,PARAMETER                            ::DEBUG=.FALSE.,VERB=.FALSE.
Double precision                             ::aa,bb,mu,sigma,theta,amin,amax,f_pg_sun,ran1,gasdev
DOUBLE PRECISION,DIMENSION(NMC)              ::XMC  !this is the factor with the initial conditions

!for each random variable, draw an initial condition for the specified kind of distribution
Do i=1,NMC

   IF(DEBUG)WRITE(*,*)'Random number variable',i,idum

   SELECT CASE(distkind(i))

   CASE(1)
      IF(DEBUG) WRITE(*,*) 'Single constant value: all values constant to one value'
      XMC(i)=params(i,1)
      IF(debug) WRITE(*,*)XMC(i)
      
   CASE(2)
      IF(DEBUG) WRITE(*,*) 'Uniform distribution'
      aa=params(i,1)
      bb=params(i,2)
      IF(debug) WRITE(*,*) aa,bb
      XMC(i)=ran1(idum)*(bb-aa)+aa
         
   CASE(3)
      IF(DEBUG) WRITE(*,*) 'Uniform distribution in log'
      aa=params(i,1)
      bb=params(i,2)
      IF(debug) WRITE(*,*) aa,bb
      XMC(i)=10D0**(ran1(idum)*(LOG10(bb)-LOG10(aa))+LOG10(aa))
   
   CASE(4)
      IF(DEBUG) WRITE(*,*) 'Normal distribution: Parameters mu,sigma; sigma>0.&
              &Points outside the allowed domain will be rejected, and a new randow number&
              &is drawn.'
      mu   =params(i,1)
      sigma=params(i,2)
      amin =params(i,3)
      amax =params(i,4)
      IF(debug) WRITE(*,*) mu,sigma,amin,amax
      DO
         XMC(i)=sigma*gasdev(idum)+mu
         IF(XMC(i)>amin .AND.  XMC(i)<amax) EXIT
      END DO

   CASE(5)
      IF(verb) WRITE(*,*) 'Lognormal distribution with the natural logarithm:&
           &Parameters mu, sigma, theta; sigma>0, theta<Xmax.&
           &Points outside the tabulated domain will be rejected, and a new randow number&
           &is drawn. Dont chose mu and sigma so that exp(mu-sigma**2) is too far outside [amin,Xmaa]'
      mu   =params(i,1)
      sigma=params(i,2)
      theta=params(i,3)
      amin =params(i,4)
      amax =params(i,5)
      DO
         XMC(i)=EXP(sigma*gasdev(idum)+mu)+theta
         IF(XMC(i)>amin .AND.  XMC(i)<amax) EXIT
      END DO
      
   CASE(6)
      IF(verb) WRITE(*,*) 'Exponential distribution: Parameters sigma, theta; sigma>0, theta<Xmax.&
           &Points outside the tabulated domain will be rejected, and a new randow number&
           &is drawn. !' 
      sigma=params(i,1)
      theta=params(i,2)
      amin =params(i,4)
      amax =params(i,5)      
      DO
         XMC(i)=-sigma*LOG(ran1(idum))+theta
         IF(XMC(i)>amin .AND.  XMC(i)<amax) EXIT
      END DO

   CASE(7)
      IF(verb) WRITE(*,*) 'Lognormal distribution with the  log10:&
           &Parameters mu, sigma, theta; sigma>0, theta<Xmax.&
           &Points outside the tabulated domain will be rejected, and a new randow number&
           &is drawn. Dont chose mu and sigma so that exp(mu-sigma**2) is too far outside [Xmin,Xmax]'
      mu   =params(i,1)
      sigma=params(i,2)
      theta=params(i,3)
      amin =params(i,4)
      amax =params(i,5)       
      DO
         XMC(i)=10**(sigma*gasdev(idum)+mu)+theta
         IF(XMC(i)>amin .AND.  XMC(i)<amax) EXIT
      END DO
         
   CASE(8)
      IF(verb) WRITE(*,*) 'Lognormal distribution with the  log10 for f_pg:&
           &Parameters mu_FeH, sigma_FeH, f_pg_sun; sigma>0, theta<Xmax.&
           &Points outside the tabulated domain will be rejected, and a new randow number&
           &is drawn. Dont chose mu and sigma so that exp(mu-sigma**2) is too far outside [Xmin,Xmax]'
      mu      =params(i,1)
      sigma   =params(i,2)
      f_pg_sun=params(i,3)
      amin    =params(i,4)
      amax    =params(i,5) 

      mu=mu+LOG10(f_pg_sun)
      DO
         XMC(i)=10D0**(sigma*gasdev(idum)+mu)
         IF(XMC(i)>amin .AND.  XMC(i)<amax) EXIT
      END DO
   END SELECT
      

END Do

MStar=XMC(1)
Rindisk=XMC(2)
Routdisk=XMC(3)
feh=XMC(4)
fg=XMC(5)

taudisk=XMC(6)
ap=XMC(7)

!Convert to cgs
Mstar=Mstar*Msol
Rindisk=Rindisk*AU
Routdisk=Routdisk*AU
taudisk=taudisk*an*1D6
ap=ap*AU

IF(DEBUG)THEN
   WRITE(*,*) Mstar/Msol
   WRITE(*,*) Rindisk/AU
   WRITE(*,*) Routdisk/AU
   WRITE(*,*) taudisk/an/1e6
   WRITE(*,*) ap/AU
END IF

IF(DEBUG)WRITE(66,*)Mstar/Msol,fg,feh,taudisk/an/1e6,ap/AU


end subroutine makeinitcond
