SUBROUTINE popsynth

!(c) Christoph Mordasini, University of Bern, 2015
!generate synthetic population by reading in the probability distribution
!drawing from them initial conditions
!starting the formation program

IMPLICIT NONE
INCLUDE 'units.h90'

INTEGER,PARAMETER                                       ::NMC=7,MAXPARAMS=5
LOGICAL,PARAMETER                                       ::AFF=.TRUE.
LOGICAL                                                 ::writeTrack
INTEGER,DIMENSION(NMC)                                  ::distkind 
DOUBLE PRECISION,DIMENSION(NMC,MAXPARAMS)               ::params
INTEGER                                                 ::nsynth,idum,iplanet
DOUBLE PRECISION                                        ::MStar,Rindisk,Routdisk,fg,feh,taudisk,ap
DOUBLE PRECISION                                        ::pT,alpha,fpgsun,kappa,pKH,qKH,C1,C2,CMdotc
INTEGER                                                 ::ilimMe,itypeI,itypeII

!output files
CHARACTER(LEN=5)                                        ::ipstr
CHARACTER(LEN=100)                                      ::outfile

!get probability distributions
CALL getmcdists(NMC,MAXPARAMS,nsynth,distkind,params)

WRITE(*,*)'We generate ',nsynth,'synthetic planets'
!READ(*,*)

!do not write formation tracks in this mode
writeTrack=.FALSE. 

!but write global output files at specific times  
OPEN(95,file='ref_red1e5.dat')
OPEN(96,file='ref_red1e6.dat')
OPEN(97,file='ref_red1e7.dat')
OPEN(98,file='ref_red1e8.dat')
OPEN(99,file='ref_red1e9.dat')
OPEN(100,file='ref_red1e10.dat')

!initialize the random number generator
idum=-12345

!read the parameters
CALL getparams(pT,alpha,fpgsun,kappa,pKH,qKH,ilimMe,itypeI,C1,itypeII,C2,CMdotc)

!loop over all synthetic planets
DO iplanet=1,Nsynth
   !draw initial conditions from probability distributions
   CALL makeinitcond(NMC,MAXPARAMS,distkind,params,idum,MStar,Rindisk,Routdisk,feh,fg,taudisk,ap)

   !start the formation model
   CALL globalPFE(writeTrack,AFF,iplanet,Mstar,Rindisk,Routdisk,feh,fg,taudisk,ap,&
        pT,alpha,fpgsun,kappa,pKH,qKH,ilimMe,itypeI,C1,itypeII,C2,CMdotc)
END DO

WRITE(*,*)
WRITE(*,*)'Synthetic population generated'

RETURN
END SUBROUTINE popsynth
