def TraubPlanetRadius(massEarth):
  '''
   convert planet mass to planet radius
    using a smooth function that is correct for the Earth and Jupiter
   there's no physics here; just a simple fit
  '''  

  if massEarth==0:
    exit('ERROR: zero mass in Mass-to-Radius conversion')
    
# Traub2011 formula, modified to enforce Earth/Jupiter fit
  r0=0.375
  r1=11.   
  m1=1000.
  w=1.5  

  radiusEarth=r0 + (r1-r0)/(1. + (math.log10(massEarth/m1)/w)**4)

# extra modification: for small planets, use the Earth's density
  if massEarth < 1:
    radiusEarth=massEarth**(1./3.)

  return radiusEarth

def TraubPlanetMass(radiusEarth):
  '''
    calculate the reverse - mass given the radius.
    this is tricky since it is not a monotonic function.
    the mass is undefined for large (>Rjup) and small (<r0) radius
  '''
  if radiusEarth==0:
    exit('ERROR: zero radius in Radius-to-Mass conversion')
  
# Traub2011 formula, modified to enforce Earth/Jupiter fit
  r0=0.375
  r1=11.   
  m1=1000.
  w=1.5  
  if radiusEarth > r1:
#for radius larger than Jupiter, just assume Jupiter mass I guess. not good.
    massEarth=2.e30/6.e27
#for planets smaller than Earth, assume Earth density
#  (so that the distribution is continuous; no breaks)
  elif radiusEarth < 1:
    massEarth=radiusEarth**3
  else:
# regular formula:
    massEarth=m1*10.**(-w*((r1-radiusEarth)/(radiusEarth-r0))**0.25)

  return massEarth

#_________________________________________________________________


def plotMassRadiusRelation():
  '''
   plot the prescribed Mass-Radius formula 
  '''
  
  figgy=figure(figsize=(6.,6.))
  subplots_adjust(left=0.15)
  subplots_adjust(right=0.95)
  subplots_adjust(bottom=0.15)
  subplots_adjust(top=0.95)
  ax=subplot(1,1,1)

  loglog()

  masses=numpy.logspace(-3.,3.,num=100)
  radii=[]
  for i in range(len(masses)):
    radii.append(TraubPlanetRadius(masses[i]))

  line1,=plot(masses,radii,'k',linewidth=2)

# also plot the reverse formula, as a check and to show degeneracy problem
  if 1:
    radii=numpy.logspace(-1.,2.,num=200)
    masses=[]
    for i in range(len(radii)):
      masses.append(TraubPlanetMass(radii[i]))
    line2,=plot(masses,radii,'r',linestyle='--',linewidth=1)


# add some points for the Solar System planets
  planetData=SSdata()
# normalize to Earth mass/radius
  ssR=array(planetData['R'])/6.37e6
  ssM=array(planetData['M'])/6.e24
  SSpoints=scatter(ssM,ssR,edgecolor='darkblue',
                   marker='o',s=30,linewidth=3)

  legend([line1,line2,SSpoints],
         ['$R_p=f(M_p)$','$M_p=f(R_p)$','Solar System planets'],
         frameon=True, loc=2)
#         frameon=True, loc=2, bbox_to_anchor=(0.05, 1.0))
  
  xlim(0.01,1000.)
  ylim(0.3,30.)

  ax.xaxis.set_major_formatter(FormatStrFormatter('%2g'))
  ax.yaxis.set_major_formatter(FormatStrFormatter('%2g'))
  
  xlabel('M$_{\\rm p}$ (M$_{\\oplus}$)',fontsize=20)
  ylabel('R$_{\\rm p}$ (R$_{\\oplus}$)',fontsize=20)

  savefig('MassvsRadius.png')
  return
#_________________________________________________________________

def SSdata():
  '''
   load in some data for planets in the Solar System
  '''

  data={'R':[],'M':[],'semia':[],'P':[],'ecc':[]}

  data['M'].append(3.3022e23)
  data['R'].append(2.4397e6)
  data['semia'].append(57.91e9)
  data['P'].append(87.969*24.*3600.)
  data['ecc'].append(.2056)
  
  data['M'].append(4.8685e24)
  data['R'].append(6.0518e6)
  data['semia'].append(108.21e9)
  data['P'].append(224.701*24.*3600.)
  data['ecc'].append(.0067)
  
  data['M'].append(5.9736e24)
  data['R'].append(6.371e6)
  data['semia'].append(149.60e9)
  data['P'].append(365.256*24.*3600.)
  data['ecc'].append(.0167)
  
  data['M'].append(6.4185e23)
  data['R'].append(3.390e6)
  data['semia'].append(227.92e9)
  data['P'].append(686.98*24.*3600.)
  data['ecc'].append(.0935)
  
  data['M'].append(1.8986e27)
  data['R'].append(69.911e6)
  data['semia'].append(778.57e9)
  data['P'].append(4332.*24.*3600.)
  data['ecc'].append(.0489)
  
  data['M'].append(5.6846e26)
  data['R'].append(58.232e6)
  data['semia'].append(1433.e9)
  data['P'].append(10759.*24.*3600.)
  data['ecc'].append(.0565)
  
  data['M'].append(8.6810e25)
  data['R'].append(25.362e6)
  data['semia'].append(2872.46e9)
  data['P'].append(30685.4*24.*3600.)
  data['ecc'].append(.0457)
  
  data['M'].append(10.243e25)
  data['R'].append(26.624e6)
  data['semia'].append(4495.06e9)
  data['P'].append(60189.0*24.*3600.)
  data['ecc'].append(.0113)

# goodnight, sweet prince
#  data['M'].append(1.25e22)
#  data['R'].append(1.195e6)
#  data['semia'].append(5906.e9)
#  data['P'].append(90465.*24.*3600.)
#  data['ecc'].append(.2488)

  return data
#_________________________________________________________________
