import matplotlib
from matplotlib import *
from pylab import *
#______________________________________________________________________________

def plotPlanetPhaseSpace(allPlanets,synthPop):

  figgy=figure(figsize=(6.,6.))
  subplots_adjust(left=0.17)
  subplots_adjust(right=0.97)
  subplots_adjust(bottom=0.12)
  subplots_adjust(top=0.92)
#  subplots_adjust(wspace=0.4)
  ax=subplot(1,1,1)
  
  title('All Planets',fontsize=20)

  loglog()

# 1. first plot the real data

# roughly convert msini into a true mass
#  plot each point at the median expectation from random inclination
#  M=Msini/sin(60)=1.15*Msini
  Mconversion=1./sin(pi/3.)
  print 'multiplying Msini by',Mconversion, \
        'as approximation of true mass'
#  scatter(semia,msini*Mconversion,
#       color='w',edgecolor=params['rvColor'],s=50,marker='^')

  semia_fromRV=[]
  mass_fromRV=[]
  semia_fromTransit=[]
  mass_fromTransit=[]
  semia_fromOther=[]
  mass_fromOther=[]

  nplanets=len(allPlanets['pl_name'])
  for i in range(nplanets):
    if allPlanets['pl_orbsmax'][i]:
      semia=allPlanets['pl_orbsmax'][i]

      mass=''
      if allPlanets['pl_masse'][i]:
        mass=allPlanets['pl_masse'][i]

      elif allPlanets['pl_msinie'][i]:
        mass=allPlanets['pl_msinie'][i]*Mconversion

      elif allPlanets['pl_rade'][i]:
        if allPlanets['pl_rade'][i]>1.5*11. and \
           allPlanets['koi_disposition'][i]=='CANDIDATE':
# maybe don't include it if it's a candidate planet with radius > 1.5 R_Jup.
# (there's a bunch of large planet radii in the KOI table that are suspect)
          pass
        else:
          pass
        mass=TraubPlanetMass(allPlanets['pl_rade'][i])

      else:
#  beta Pic b and HR 8799 e  are missing info
#        print 'PROBLEM: no mass or radius:',allPlanets['pl_name'][i]
        pass

      if mass:
#        print allPlanets.keys()
        if allPlanets['pl_discmethod'][i]=='Radial Velocity':
          semia_fromRV.append(semia)
          mass_fromRV.append(mass)
        elif allPlanets['pl_discmethod'][i]=='Transit' or \
                 allPlanets['kepid'][i]:
          semia_fromTransit.append(semia)
          mass_fromTransit.append(mass)
        else:
#          print 'Other discovery method',allPlanets['pl_discmethod'][i]
          semia_fromOther.append(semia)
          mass_fromOther.append(mass)
        
  print '# of RV/transit/other planets', \
        len(semia_fromRV),len(semia_fromTransit),len(semia_fromOther)
        
# use a different symbol to indicate the discovery method
#  triangle for radial velocity
#  circle for transit
#  cross for others
# 
  scatter(semia_fromRV,mass_fromRV,
          color='w',edgecolor=params['rvColor'],
          s=params['pointSize'],marker='^',
          label='RV discoveries')
  scatter(semia_fromTransit,mass_fromTransit,
          color='w',edgecolor=params['transitColor'],
          s=params['pointSize'],marker='o',
          label='transit discoveries')
#          alpha=0.5,
  scatter(semia_fromOther,mass_fromOther,
          color='w',edgecolor=params['otherColor'],
          s=params['pointSize'],marker='+',
          label='other discoveries')

# 2. then overlay the model data

  if synthPop:
    scatter(array(synthPop['ap']),
            array(synthPop['Mp']),
            color=params['modelColor'],
            edgecolor=params['modelColor'],
            s=params['pointSize'],alpha=0.5,
            label='simulation')

# check if the two distributions are different from each other
    checkDiff(semia_fromRV+semia_fromTransit+semia_fromOther,
              synthPop['ap'],'semi-major axis')
    checkDiff(mass_fromRV+mass_fromTransit+mass_fromOther,
              synthPop['Mp'],'planet mass')

  legend(frameon=True,fontsize=12,loc=4)

# set plot limits in AU
  xlim(0.01,100.)
# set plot limits in Earth masses
  ylim(5.e-2,2.e4)
  ylim(2.e-2,5.e4)
  
  ax.xaxis.set_major_formatter(FormatStrFormatter('%2g'))
  ax.yaxis.set_major_formatter(FormatStrFormatter('%2g'))

  xlabel('semi-major axis (AU)',fontsize=20)  
  ylabel('M$_{\\rm p}$ (M$_{\\oplus}$)',fontsize=20)

# show()
  savefig('semiaVSmass.png')
            
  return
#______________________________________________________________________________

def plotRVcomparison(allPlanets,RVselectedPop):

  figgy=figure(figsize=(6.,6.))
  subplots_adjust(left=0.17)
  subplots_adjust(right=0.97)
  subplots_adjust(bottom=0.12)
  subplots_adjust(top=0.92)
  ax=subplot(1,1,1)
  
  title('Radial-Velocity Planets',fontsize=20)
  
  loglog()

# first plot the real data
# only include systems discovered by RV
  RVdata=RVdataSelect(allPlanets)
  scatter(array(RVdata['semia']),
          array(RVdata['msini']),
          color='w',marker='^',
          edgecolor=params['rvColor'],
          s=params['pointSize'],
          label='observations')
  
# only plot the selected synthetic data
  if RVselectedPop:
    scatter(array(RVselectedPop['ap']),
            array(RVselectedPop['Msini']),
            color=params['modelColor'],alpha=0.5,
            edgecolor=params['modelColor'],
            s=params['pointSize'],
            label='simulation')

# check if the two distributions are different from each other
    checkDiff(RVdata['semia'],RVselectedPop['ap'],
              'semi-major axis')
    checkDiff(RVdata['msini'],RVselectedPop['Msini'],
              'planet mass*sin(i)')

# optionally draw a dashed line showing the detection limit for 1 m/s
#  assume the star has solar mass
  if False:
    MEarthtoMSun=5.972e27/1.99e33
    Vkep1AU=2.97e4  
    semia=array([1.e-3,1.e3])
    Msini=sqrt(semia)/MEarthtoMSun/Vkep1AU
    plot(semia,Msini,linestyle='--',color='k')

  legend(frameon=True,fontsize=12,loc=4)

# set x-axis range (in AU) and y-axis range(in Earth masses)
  xlim(0.01,100.)
  ylim(5.e-2,2.e4)
  ylim(2.e-2,5.e4)

  ax.xaxis.set_major_formatter(FormatStrFormatter('%2g'))
  ax.yaxis.set_major_formatter(FormatStrFormatter('%2g'))

  xlabel('semi-major axis (AU)',fontsize=20)  
  ylabel('M$_{\\rm p}$ sin($i$) (M$_{\\oplus}$)',fontsize=20)

  savefig('RVcomparison.png')
  return
#______________________________________________________________________________

def plotTransitComparison(allPlanets,transitSelectedPop):

  figgy=figure(figsize=(6.,6.))
  subplots_adjust(left=0.17)
  subplots_adjust(right=0.97)
  subplots_adjust(bottom=0.12)
  subplots_adjust(top=0.92)
  ax=subplot(1,1,1)
  
  title('Kepler Planets',fontsize=20)
  
  loglog()

# first plot the real data
#  only include systems discovered by Kepler
  keplerData=keplerSelect(allPlanets)
#  print 'len check',len(keplerData['semia'])
#  print 'len check',len(keplerData['Rp'])
#  print 'len check',len(keplerData['Mp'])
#  scatter(array(keplerData['semia']),array(keplerData['Mp']),
  for i in range(len(keplerData['semia'])):
    if not keplerData['semia'][i]:
      print 'trouble: no semia for kepler planet'
    if not keplerData['Rp'][i]:
      print 'trbu2',keplerData['semia'][i],keplerData['Rp'][i]
      for key in keplerData:
        print '  ',key,keplerData[key][i]
  
  scatter(array(keplerData['semia']),
          array(keplerData['Rp']),
          color='w',
          edgecolor=params['transitColor'],
          s=params['pointSize'],
          label='observations')

# next plot the synthetic population
#  only plot the transit-selected data
#
  if transitSelectedPop:
    scatter(array(transitSelectedPop['ap']),
            array(transitSelectedPop['Rp']),
            color=params['modelColor'],alpha=0.5,
            edgecolor=params['modelColor'],
            s=params['pointSize'],
            label='simulation')

# check if the two distributions are different from each other
    checkDiff(keplerData['semia'],transitSelectedPop['ap'],
              'semi-major axis')
    checkDiff(keplerData['Rp'],transitSelectedPop['Rp'],
              'planet radius')
    
  legend(frameon=True,fontsize=12,loc=4)
         
# set x-axis range (in AU) and y-axis range(in Earth masses)
  xlim(0.01,10.)
  xlim(0.01,100.)
  ylim(2.e-1,5.e2)
# note: there are some screwy candidates outside of this range
#  one planet has radius <0.1 REarth; another is at 45 AU
# also note that there's that batch of crazy-large-radius candidates

  ax.xaxis.set_major_formatter(FormatStrFormatter('%2g'))
  ax.yaxis.set_major_formatter(FormatStrFormatter('%2g'))

#  ticks=ax.yaxis.get_ticklocs()
#  ax.set_yticklabels(ticks)
#  print 'tick labs',ax.xaxis.get_ticklocs()

  xlabel('semi-major axis (AU)',fontsize=20)  
#  ylabel('M$_{\\rm p}$ (M$_{\\oplus}$)',fontsize=20)
  ylabel('R$_{\\rm p}$ (R$_{\\oplus}$)',fontsize=20)

  savefig('keplerComparison.png')

# test plot for histograms. not great
#  plotKeplerHisto(keplerData,transitSelectedPop)

  return
#______________________________________________________________________________

def plotKeplerHisto(keplerData,transitSelectedPop):

  figgy=figure(figsize=(10.,10.))
  subplots_adjust(left=0.10)
  subplots_adjust(right=0.95)
  subplots_adjust(bottom=0.10)
  subplots_adjust(top=0.95)
  subplots_adjust(wspace=0.4)

  nparam=2
  if transitSelectedPop:
    nparam=4
    
    transitSelectedPop['Rp']=[]
    if transitSelectedPop:
      for i in range(len(transitSelectedPop['Mp'])):
        convertedRadius=TraubPlanetRadius(transitSelectedPop['Mp'][i])
        transitSelectedPop['Rp'].append(convertedRadius)

  nbins=30

  for iparam in range(nparam):
    ax=subplot(2,nparam/2,iparam+1)

    if iparam==0:
      data=keplerData['semia']
      varName='semi-major axis (AU)'
      color=params['transitColor']
      xmin,xmax=1.e-2,1.e1      
    elif iparam==1:
      data=keplerData['Rp']
      varName='R$_{\\rm p}$ (R$_{\\oplus}$)'
      color=params['transitColor']
      xmin,xmax=2.e-1,5.e2
    elif iparam==2:
      data=transitSelectedPop['ap']
      varName='semi-major axis (AU)'
      color=params['modelColor']
      xmin,xmax=1.e-2,1.e1
    elif iparam==3:
      data=transitSelectedPop['Rp']
      varName='R$_{\\rm p}$ (R$_{\\oplus}$)'
      color=params['modelColor']
      xmin,xmax=2.e-1,5.e2
    elif iparam==4:
      exit('undefined panel for histo')

    if data:
      bins=numpy.logspace(log10(xmin),log10(xmax),nbins)
      n,bins,patch1 = hist(data,
                           bins=bins,
                           log=True,
                           color=color, 
                           histtype='stepfilled')
#                           bins=nbins,
#                           range=[xmin,xmax],
      gca().set_xscale("log")

#    print 'bins',bins

    ylims=ylim()
    ylim(0.5,ylims[1])
    ax.xaxis.set_major_formatter(FormatStrFormatter('%2g'))
    ax.yaxis.set_major_formatter(FormatStrFormatter('%2g'))
    xlabel(varName,fontsize=16)
    ylabel('# of planets',fontsize=20)

  savefig('keplerComparisonHisto.png')
  return
#______________________________________________________________________________


